{-# LANGUAGE UnboxedTuples #-}

foo = (# 1, 2, 3 #)

bar =
  (#
    1,
    2,
    3
  #)

unit :: (# #)
unit = (# #)
